import numpy as np
import matplotlib.pyplot as plt
from astropy.table import Table, join
from astropy.coordinates import SkyCoord
from astropy import coordinates as coord
import astropy.units as u
from astropy.coordinates import FK5
from astropy.io import fits
import string
from lmfit import Model
import sys
import matplotlib.ticker as ticker

CANTAT = Table.read('../../TABLE/cantat_2020_aa_640_A1.dat', format='ascii')
CANTAT['col15'].name = 'age'

BOSSINI = Table.read('../../TABLE/Bossini2019.dat', format='ascii')
BOSSINI = BOSSINI[np.where(BOSSINI['col17'] != 'NC')]
def d(dismod):
    dis = 10**((dismod+5)/5)
    return dis
BOSSINI['col1'].name = 'Cluster'
BOSSINI['col7'].name = 'mu' # (m_M)_0
BOSSINI['dist'] = d(BOSSINI['mu'])/1000.
BOSSINI['col4'].name = 'log_t'
BOSSINI['age'] = (10**BOSSINI['log_t'])/10**9
BOSSINI['col16'].name = '[Fe/H]' 
BOSSINI_c = SkyCoord(ra = BOSSINI['col2']*u.degree,
                    dec = BOSSINI['col3']*u.degree,
                    distance = BOSSINI['dist']*u.kpc,
                    frame='icrs')
BOSSINI_c = BOSSINI_c.transform_to(coord.Galactocentric(galcen_distance=8*u.kpc))
BOSSINI_rgc = np.sqrt(BOSSINI_c.x**2 + BOSSINI_c.y**2 + BOSSINI_c.z**2)
BOSSINI['Rgc'] = BOSSINI_rgc
bossini_dat = Table()
bossini_dat = BOSSINI['Cluster', 'age', 'Rgc', '[Fe/H]']
bossini_dat['age'].name = 'age_bossini'
bossini_dat['Rgc'].name = 'Rgc_bossini'
bossini_dat['[Fe/H]'].name = '[Fe/H]_bossini'


BOCCE = Table.read('../../TABLE/BOCCE.csv', format='csv')
BOCCE.remove_row(17)
bocce_dat = Table()
bocce_dat = BOCCE['Cluster', 'age (Gyr)', 'Rgc (Rgc,sun=8)', '[Fe/H]']
bocce_dat['age (Gyr)'].name = 'age_bocce'
bocce_dat['Rgc (Rgc,sun=8)'].name = 'Rgc_bocce'
bocce_dat['[Fe/H]'].name = '[Fe/H]_bocce'


netopil = Table.read('../../TABLE/Netopil_2016_tab1.fits', format='fits')
netopil['Cluster'] = netopil['Cluster'].astype(str)
netopil['Name'] = netopil['Cluster']
netopil_new_name = []
for i in np.arange(len(netopil)):
    netopil_new_name.append(netopil['Name'][i].replace(" ", ""))
netopil['Cluster'] = netopil_new_name
netopil.remove_rows([17,166]) # 17 Berkeley 75 / 166 Saurer1 - e_Fe_H = 0

#donor = Table.read('../../TABLE/Donor_2020.fits', format='fits')
donor = fits.open('../../TABLE/J_AJ_159_199_table1.dat.fits')
donor = Table.read(donor)
donor['Name'] = donor['Name'].astype(str)
donor_new_name = []
for i in np.arange(len(donor)):
    donor_new_name.append(donor['Name'][i].replace(" ",""))
donor['Cluster'] = donor_new_name
donor.remove_row(60)
donor_old_idx = np.where(donor['Age'] > 1.0)
donor_old = donor[donor_old_idx]
donor_dat = Table()
donor_dat = donor['Cluster', 'Age', 'Rgc', 'Fe/H', 'e_Fe/H']
donor_dat['Age'].name = 'age_donor'
donor_dat['Rgc'].name = 'Rgc_donor'
donor_dat['Fe/H'].name = '[Fe/H]_donor'
donor_dat['e_Fe/H'].name = 'e_[Fe/H]_donor'

dias = Table.read('../../TABLE/Dias_2021.fit', format='fits')
dias['Cluster'].name = 'Name'
dias['Name'] = dias['Name'].astype(str)
name = np.array(dias['Name'])
new_name = []
for i in name:
    new_name.append(i.replace("_", ""))
dias['Cluster'] = new_name
dias.remove_rows([269]) # 269 Czerink 30 : Dias 2021
dias_temp = SkyCoord(ra=dias['RA_ICRS'], dec=dias['DE_ICRS'], unit=(u.deg, u.deg), frame='icrs', distance=dias['Dist'])
dias_temp = dias_temp.transform_to(coord.Galactocentric(galcen_distance=8*u.kpc))
dias['Rgc'] = np.sqrt(dias_temp.x**2 + dias_temp.y**2 + dias_temp.z**2) / 1e3
dias['Rgc'].unit = u.kpc
dias['age'] = (10**dias['logage'])/1e9
dias.remove_row(269) # 269 Czernik 30
dias_dat = Table()
dias_dat = dias['Cluster', 'age', 'Rgc', '__Fe_H_', 'e__Fe_H_']
dias_dat['age'].name = 'age_dias'
dias_dat['Rgc'].name = 'Rgc_dias'
dias_dat['__Fe_H_'].name = '[Fe/H]_dias'
dias_dat['e__Fe_H_'].name = 'e_[Fe/H]_dias'


dat = Table.read('../../TABLE/Dias_2002.fits', format='fits')
dat['Cluster'].name = 'Name'
dat_new_name = []
for i in np.arange(len(dat)):
    dat_new_name.append(dat['Name'][i].replace(" ", ""))
dat['Cluster'] = dat_new_name
test_ra = []
test_dec = []
for i in np.arange(len(dat)):
    test_ra.append(str(dat['RAh'][i]) + ':' + str(dat['RAm'][i]) + ':' + str(dat['RAs'][i]))
    test_dec.append(str(dat['DE-'][i]) + str(dat['DEd'][i]) + ':' + str(dat['DEm'][i]) + ':' + str(dat['DEs'][i]))

dat['ra'] = test_ra
dat['dec'] = test_dec
ra = dat['ra']
dec = dat['dec']
#dat['_18'].name='[Fe/H]'
#dat['Dist'].name='dist'
dat['dist'] = dat['Dist'].data/1e3
dat['Age'].name = 'logt'
test = SkyCoord(ra=ra, dec=dec, unit=(u.hourangle, u.deg), frame=FK5, distance=dat['dist']*u.kpc)
test = test.transform_to(coord.Galactocentric(galcen_distance=8*u.kpc))
dat['X'] = test.x
dat['Y'] = test.y
dat['Z'] = test.z
dat['Rgc'] = np.sqrt(test.x**2 + test.y**2 + test.z**2)
t = (10**dat['logt'])/10**9
dat['age'] = t
non = np.where(dat['logt'] == 0)
dat['age'][non] = -99
non_feh = np.where(dat['[Fe/H]'] == 0)
feh = np.ma.array(dat['[Fe/H]'].data)
feh[non_feh] = np.ma.masked
dat['[Fe/H]'] = feh
#dat['age'].fill_value = -99
#dat['age'] = dat['age'].filled()
"""
dat = Table.read('../../TABLE/Dias_2002.csv', format='csv')
dat['col0'].name = 'Name'
dat_new_name = []
for i in np.arange(len(dat)):
    dat_new_name.append(dat['Name'][i].replace(" ", ""))
dat['Cluster'] = dat_new_name
dat['_1'].name = 'ra'
dat['_2'].name = 'dec'
ra = dat['ra']
dec = dat['dec']
dat['_18'].name = '[Fe/H]'
dat['_19'].name = 'e_[Fe/H]'
dat['_5'].name = 'dist'
dat['dist'] = dat['dist']/1e3
dat['_7'].name = 'logt'
test = SkyCoord(ra=ra, dec=dec, unit=(u.hourangle, u.deg), frame=FK5, distance=dat['dist']*u.kpc)
test = test.transform_to(coord.Galactocentric(galcen_distance=8*u.kpc))
dat['X'] = test.x
dat['Y'] = test.y
dat['Z'] = test.z
dat['Rgc'] = np.sqrt(test.x**2 + test.y**2 + test.z**2)
t = (10**dat['logt'])/10**9
dat['age'] = t
dat['age'].fill_value = -99
dat['age'] = dat['age'].filled()
"""
dat.remove_rows([590,550,616,717]) # 590 Berkeley 34 / 550 Berkeley 75 / 616 Berkeley 76 / 717 Czernik 30: Dias 2002
dias_02_dat = Table()
dias_02_dat = dat['Cluster', 'age', 'e_[Fe/H]', 'Rgc', '[Fe/H]']
dias_02_dat['age'].name = 'age_DAML'
dias_02_dat['Rgc'].name = 'Rgc_DAML'
dias_02_dat['[Fe/H]'].name = '[Fe/H]_DAML'
dias_02_dat['e_[Fe/H]'].name = 'e_[Fe/H]_DAML'

spina1 = fits.open('../../TABLE/J_MNRAS_503_3279_table2.dat.fits')
spina1 = Table.read(spina1[1])
spina2 = fits.open('../../TABLE/J_MNRAS_503_3279_table3.dat.fits')
spina2 = Table.read(spina2[1])
spina = join(spina1, spina2, keys='Cluster')
spina['age'] = (10**spina['logAge'])/1e9
spina_new_name = []
for i in np.arange(len(spina)):
    new = spina['Cluster'][i].replace("_", "")
    new = new.translate({ord(c): None for c in string.whitespace})
    spina_new_name.append(new)
spina['Cluster'] = spina_new_name
spina_temp = SkyCoord(ra=spina['RAdeg'], dec=spina['DEdeg'], unit=(u.deg, u.deg), frame=FK5, distance=spina['dist'])
spina_temp = spina_temp.transform_to(coord.Galactocentric(galcen_distance=8*u.kpc))
spina['Rgc_spina'] = np.sqrt(spina_temp.x**2 + spina_temp.y**2 + spina_temp.z**2)
spina_dat = Table()
spina_dat = spina['Cluster', 'age', 'Rgc_spina', '[Fe/H]', 'e_[Fe/H]']
spina_dat['[Fe/H]'].name = '[Fe/H]_spina'
spina_dat['e_[Fe/H]'].name = 'e_[Fe/H]_spina'
spina_dat['age'].name = 'age_spina'

com1 = join(dias_dat, dias_02_dat, keys='Cluster', join_type='outer')
com2 = join(com1, donor_dat, keys='Cluster', join_type='outer')
com3 = join(com2, netopil, keys='Cluster', join_type='outer')
com4 = join(com3, bocce_dat, keys='Cluster', join_type='outer')
com5 = join(com4, spina_dat, keys='Cluster', join_type='outer')

young_idx_DAML = []
young_idx_bocce = []
young_idx_dias = []
young_idx_spina = []
young_idx_netopil_HQS = []
young_idx_netopil_LQS = []
young_idx_netopil_phot = []
young_idx_donor = []
rgc_young = []
Fe_H_young = []
e_Fe_H_young = []

old_idx_DAML = []
old_idx_bocce = []
old_idx_dias = []
old_idx_spina = []
old_idx_netopil_HQS = []
old_idx_netopil_LQS = []
old_idx_netopil_phot = []
old_idx_donor = []
rgc = []
Fe_H = []
e_Fe_H = []

old_lim = 1
young_lim = 0.01
for i in np.arange(len(com5)):
    if np.ma.is_masked(com5['__Fe_H_HQS'][i]) or np.isnan(com5['__Fe_H_HQS'][i]) or np.ma.is_masked(com5['e__Fe_H_HQS'][i]) or np.isnan(com5['e__Fe_H_HQS'][i]):
        if np.ma.is_masked(com5['[Fe/H]_spina'][i]) or np.isnan(com5['[Fe/H]_spina'][i]) or np.ma.is_masked(com5['e_[Fe/H]_spina'][i]) or np.isnan(com5['e_[Fe/H]_spina'][i]):
            if np.ma.is_masked(com5['__Fe_H_LQS'][i]) or np.isnan(com5['__Fe_H_LQS'][i]) or np.ma.is_masked(com5['e__Fe_H_LQS'][i]) or np.isnan(com5['e__Fe_H_LQS'][i]):
                if np.ma.is_masked(com5['[Fe/H]_donor'][i]) or np.isnan(com5['[Fe/H]_donor'][i]) or np.ma.is_masked(com5['e_[Fe/H]_donor'][i]) or np.isnan(com5['e_[Fe/H]_donor'][i]):
                    #if np.ma.is_masked(com5['[Fe/H]_bocce'][i]) or np.isnan(com5['[Fe/H]_bocce'][i]):
                    if np.ma.is_masked(com5['__Fe_H_Phot'][i]) or np.isnan(com5['__Fe_H_Phot'][i]) or np.ma.is_masked(com5['e__Fe_H_Phot'][i]) or np.isnan(com5['e__Fe_H_Phot'][i]):
                        if np.ma.is_masked(com5['[Fe/H]_dias'][i]) or np.isnan(com5['[Fe/H]_dias'][i]):
                            if np.ma.is_masked(com5['[Fe/H]_DAML'][i]) == False and np.isnan(com5['[Fe/H]_DAML'][i]) == False and np.ma.is_masked(com5['e_[Fe/H]_DAML'][i]) == False and np.isnan(com5['e_[Fe/H]_DAML'][i]) == False:
                                if com5['age_DAML'][i] >= old_lim:
                                    old_idx_DAML.append(i)
                                    rgc.append(com5['Rgc_DAML'][i])
                                    Fe_H.append(com5['[Fe/H]_DAML'][i])
                                    e_Fe_H.append(com5['e_[Fe/H]_DAML'][i])
                                else:
                                    young_idx_DAML.append(i)
                                    rgc_young.append(com5['Rgc_DAML'][i])
                                    Fe_H_young.append(com5['[Fe/H]_DAML'][i])
                                    e_Fe_H_young.append(com5['e_[Fe/H]_DAML'][i])
                        elif com5['age_dias'][i] >= old_lim:
                            old_idx_dias.append(i)
                            rgc.append(com5['Rgc_dias'][i])
                            Fe_H.append(com5['[Fe/H]_dias'][i])
                            e_Fe_H.append(com5['e_[Fe/H]_dias'][i])
                        else:
                            young_idx_dias.append(i)
                            rgc_young.append(com5['Rgc_dias'][i])
                            Fe_H_young.append(com5['[Fe/H]_dias'][i])
                            e_Fe_H_young.append(com5['e_[Fe/H]_dias'][i])
                    elif com5['Age'][i] >= old_lim:
                        old_idx_netopil_phot.append(i)
                        rgc.append(com5['RGC'][i])
                        Fe_H.append(com5['__Fe_H_Phot'][i])
                        e_Fe_H.append(com5['e__Fe_H_Phot'][i])
                    else:
                        young_idx_netopil_phot.append(i)
                        rgc_young.append(com5['RGC'][i])
                        Fe_H_young.append(com5['__Fe_H_Phot'][i])
                        e_Fe_H_young.append(com5['e__Fe_H_Phot'][i])
                    """elif com5['age_bocce'][i] >= old_lim:
                        old_idx_bocce.append(i)
                        rgc.append(com5['Rgc_bocce'][i])
                        Fe_H.append(com5['[Fe/H]_bocce'][i])
                        e_Fe_H.append(com5['e_[Fe/H]_bocce'][i])
                    else:
                        young_idx_bocce.append(i)
                        rgc_young.append(com5['Rgc_bocce'][i])
                        Fe_H_young.append(com5['[Fe/H]_bocce'][i])
                        e_Fe_H_young.append(com5['e_[Fe/H]_bocce'][i])"""
                elif com5['age_donor'][i] >= old_lim:
                    old_idx_donor.append(i)
                    rgc.append(com5['Rgc_donor'][i])
                    Fe_H.append(com5['[Fe/H]_donor'][i])
                    e_Fe_H.append(com5['e_[Fe/H]_donor'][i])
                else:
                    young_idx_donor.append(i)
                    rgc_young.append(com5['Rgc_donor'][i])
                    Fe_H_young.append(com5['[Fe/H]_donor'][i])
                    e_Fe_H_young.append(com5['e_[Fe/H]_donor'][i])
            elif com5['Age'][i] >= old_lim:
                old_idx_netopil_LQS.append(i)
                rgc.append(com5['RGC'][i])
                Fe_H.append(com5['__Fe_H_LQS'][i])
                e_Fe_H.append(com5['e__Fe_H_LQS'][i])
            else:
                young_idx_netopil_LQS.append(i)
                rgc_young.append(com5['RGC'][i])
                Fe_H_young.append(com5['__Fe_H_LQS'][i])
                e_Fe_H_young.append(com5['e__Fe_H_LQS'][i])
        elif com5['age_spina'][i] >= old_lim:
            old_idx_spina.append(i)
            rgc.append(com5['Rgc_spina'][i])
            Fe_H.append(com5['[Fe/H]_spina'][i])
            e_Fe_H.append(com5['e_[Fe/H]_spina'][i])
        else:
            young_idx_spina.append(i)
            rgc_young.append(com5['Rgc_spina'][i])
            Fe_H_young.append(com5['[Fe/H]_spina'][i])
            e_Fe_H_young.append(com5['e_[Fe/H]_spina'][i])
    elif com5['Age'][i] >= old_lim:
        old_idx_netopil_HQS.append(i)
        rgc.append(com5['RGC'][i])
        Fe_H.append(com5['__Fe_H_HQS'][i])
        e_Fe_H.append(com5['e__Fe_H_HQS'][i])
    else:
        young_idx_netopil_HQS.append(i)
        rgc_young.append(com5['RGC'][i])
        Fe_H_young.append(com5['__Fe_H_HQS'][i])
        e_Fe_H_young.append(com5['e__Fe_H_HQS'][i])

old = np.hstack([old_idx_DAML, old_idx_dias, old_idx_spina, old_idx_netopil_HQS, old_idx_netopil_LQS, old_idx_netopil_phot, old_idx_donor])
old = old.astype(np.int32)
young = np.hstack([young_idx_DAML, young_idx_dias, young_idx_spina, young_idx_netopil_HQS, young_idx_netopil_LQS , young_idx_netopil_phot, young_idx_donor])
young = young.astype(np.int32)

same_cluster = join(BOSSINI, BOCCE, keys='Cluster')
arr = np.ones(len(BOSSINI), dtype=bool)
arr[16] = False # NGC2168
arr[43] = False # NGC6819

BOSSINI = BOSSINI[arr]

cz30 = SkyCoord("07 31 10.8 -09 56 42", unit=(u.hourangle, u.deg), frame=FK5, distance=6.46*u.kpc)
cz30 = cz30.transform_to(coord.Galactocentric(galcen_distance=8*u.kpc))
cz30_dis = np.sqrt(cz30.x**2+cz30.y**2+cz30.z**2)
cz30_age = 2.82
cz30_FeH = -0.22
e_cz30_FeH = 0.15
rgc.append(cz30_dis.value)
Fe_H.append(cz30_FeH)
e_Fe_H.append(e_cz30_FeH)


be34 = SkyCoord("07 00 23.2 -00 13 54", unit=(u.hourangle, u.deg), frame=FK5, distance=6.70*u.kpc)
be34 = be34.transform_to(coord.Galactocentric(galcen_distance=8*u.kpc))
be34_dis = np.sqrt(be34.x**2+be34.y**2+be34.z**2)
be34_age = 2.51
be34_FeH = -0.30
e_be34_FeH = 0.10
rgc.append(be34_dis.value)
Fe_H.append(be34_FeH)
e_Fe_H.append(e_be34_FeH)

be75 = SkyCoord("06 48 59.1 -23 59 36", unit=(u.hourangle, u.deg), frame=FK5, distance=7.77*u.kpc)
be75 = be75.transform_to(coord.Galactocentric(galcen_distance=8*u.kpc))
be75_dis = np.sqrt(be75.x**2 + be75.y**2 + be75.z**2)
be75_age = 3.16
be75_FeH = -0.57
e_be75_FeH = 0.10
rgc.append(be75_dis.value)
Fe_H.append(be75_FeH)
e_Fe_H.append(e_be75_FeH)

be76 = SkyCoord("07 06 42.4 -11 43 33", unit=(u.hourangle, u.deg), frame=FK5, distance=6.22*u.kpc)
be76 = be76.transform_to(coord.Galactocentric(galcen_distance=8*u.kpc))
be76_dis = np.sqrt(be76.x**2 + be76.y**2 + be76.z**2)
be76_age = 1.26
be76_FeH = 0.00
e_be76_FeH = 0.10
rgc.append(be76_dis.value)
Fe_H.append(be76_FeH)
e_Fe_H.append(e_be76_FeH)

def f(x, a, b):
    return a*x + b

lim = float(sys.argv[1])
rgc = np.array(rgc)
Fe_H = np.array(Fe_H)
dist_cut = np.where(rgc < lim)

gmodel = Model(f)
x0 = rgc
result0 = gmodel.fit(Fe_H, x=rgc, a=-0.007, b=0.5)
x0 = np.arange(np.int(np.min(rgc)), np.int(np.max(rgc))+0.1)
print(result0.fit_report())

x1 = rgc[dist_cut]
result = gmodel.fit(Fe_H[dist_cut], x=rgc[dist_cut], a=-0.007, b=0.5)
x1 = np.arange(np.int(np.min(rgc)), lim+0.1, 0.1)
print(result.fit_report())

re_dist_cut = np.where(rgc >= lim)
x2 = rgc[re_dist_cut]

result2 = gmodel.fit(Fe_H[re_dist_cut], x=rgc[re_dist_cut], a=-0.009, b=-0.100)
x2 = np.arange(lim, np.max(rgc), 0.1)
print(result2.fit_report())


"""
A3 = np.vstack([rgc_young, np.ones(len(young))]).T
x3 = np.arange(np.int(np.min(rgc_young)), np.int(np.max(rgc_young)), 0.1)
Fe_H_young = np.asarray(Fe_H_young)
y_Fe_H3 = Fe_H_young[:, np.newaxis]
alpha3 = np.dot((np.dot(np.linalg.inv(np.dot(A3.T,A3)),A3.T)),y_Fe_H3)
y3 = alpha3[0] * x3 + alpha3[1]
SSE3 = np.sum(np.square(y3 - y_Fe_H3))
MSE3 = np.mean(np.square(y3 - y_Fe_H3))
"""

old_tab = Table()
old_tab['rgc'] = rgc
old_tab['Fe_H'] = Fe_H
old_tab['e_Fe_H'] = e_Fe_H
old_tab.write('old_rgc_Fe_H.dat', format='ascii.commented_header', overwrite=True)

fig = plt.figure(figsize=(9,12))
fig.subplots_adjust(hspace=0, wspace=0.)
ax0 = fig.add_subplot(411)
ax0.plot(com5['Rgc_DAML'][old_idx_DAML], com5['[Fe/H]_DAML'][old_idx_DAML],
        c='red', marker='o', ls='none', ms=2.5, 
        label='Dias+02 ({0})'.format(len(old_idx_DAML)))
ax0.plot(com5['RGC'][old_idx_netopil_phot], com5['__Fe_H_Phot'][old_idx_netopil_phot],
        c='darkorange', marker='o', ls='none', ms=2.5, 
        label='Netopil+16 ({0})'.format(len(old_idx_netopil_phot) + len(old_idx_netopil_LQS)+ len(old_idx_netopil_HQS)))
ax0.plot(com5['RGC'][old_idx_netopil_LQS], com5['__Fe_H_LQS'][old_idx_netopil_LQS],
        c='darkorange', marker='o', ls='none', ms=2.5)
ax0.plot(com5['RGC'][old_idx_netopil_HQS], com5['__Fe_H_HQS'][old_idx_netopil_HQS],
        c='darkorange', marker='o', ls='none', ms=2.5)
ax0.plot(com5['Rgc_donor'][old_idx_donor], com5['[Fe/H]_donor'][old_idx_donor],
        c='k', marker='o', ls='none',ms=2.5,
        label='Donor+20 ({0})'.format(len(old_idx_donor)))
ax0.plot(com5['Rgc_spina'][old_idx_spina], com5['[Fe/H]_spina'][old_idx_spina],
        c= 'blue', marker='o',ls='none', ms=2.5,
        label='Spina+21 ({0})'.format(len(old_idx_spina)))
ax0.plot(com5['Rgc_dias'][old_idx_dias], com5['[Fe/H]_dias'][old_idx_dias],
        c='magenta', marker='o',ls='none', ms=2.5,
        label='Dias+21 ({0})'.format(len(old_idx_dias)))

ax0.plot(cz30_dis.value, cz30_FeH,
       ms=8, mec='red', mew=2.8, mfc='none', ls='none', marker='o')
       #label='Czerink 30')
ax0.plot(be34_dis.value, be34_FeH,
        ms=8, mec='orange', mew=2.8, mfc='none', marker='o', ls='none')
        #label='Berkeley 34')
ax0.plot(be75_dis.value, be75_FeH,
        ms=8, mec='k', mew=2.8, mfc='none', marker='o', ls='none')
        #label='Berkeley 75')
ax0.plot(be76_dis.value, be76_FeH,
        ms=8, mec='blue', mew=2.8, mfc='none', marker='o',ls='none')
        #label='Berkeley 76')
ax0.plot(x0, result0.best_values['a']*x0 + result0.best_values['b'], 'r--',
        label='${0:.3f}R_{{GC}} {1:+.3f}$'.format(result0.best_values['a'], result0.best_values['b']))
ax0.set_ylabel('[Fe/H]', fontsize=18)
#ax0.text(15.3, -0.82, '(a) t $\geq$ {0} Gyr, N={1}'.format(old_lim, len(old)), size=16,c='k')#,  bbox={'facecolor': 'white', 'alpha': 0.7, 'pad': 3})
ax0.text(3.3, 0.85, '(a) t $\geq$ {0} Gyr, N={1}'.format(old_lim, len(old)+4), size=16,c='k')#,  bbox={'facecolor': 'white', 'alpha': 0.7, 'pad': 3})
ax0.tick_params(labelsize=16)
loc = ticker.MultipleLocator(base=2)
ax0.xaxis.set_major_locator(loc)
ax0.tick_params(labelbottom=False)
ax0.set_ylim(-0.9, 1.1)
ax0.set_xlim(3,22)
plt.legend(ncol=1,frameon=False)

ax = fig.add_subplot(412)
#ax.errorbar(com5['Rgc_bocce'][old_idx_bocce], com5['[Fe/H]_bocce'][old_idx_bocce], yerr=com5['e_[Fe/H]_bocce'][old_idx_bocce]'ro', ms=2.5, label='BOCCE ({0})'.format(len(old_idx_bocce)))
"""
ax.errorbar(com5['Rgc_DAML'][old_idx_DAML], com5['[Fe/H]_DAML'][old_idx_DAML], yerr=com5['e_[Fe/H]_DAML'][old_idx_DAML], 
        capsize=1, c='red', marker='o', ls='none', ms=2.5,ecolor='grey',elinewidth=0.5, 
        label='Dias+02 ({0})'.format(len(old_idx_DAML)))
ax.errorbar(com5['RGC'][old_idx_netopil_phot], com5['__Fe_H_Phot'][old_idx_netopil_phot], yerr=com5['e__Fe_H_Phot'][old_idx_netopil_phot],
        capsize=1, c='darkorange', marker='o', ls='none', ms=2.5, ecolor='grey',elinewidth=0.5,
        label='Netopil+16 ({0})'.format(len(old_idx_netopil_phot) + len(old_idx_netopil_LQS)+ len(old_idx_netopil_HQS)))
ax.errorbar(com5['RGC'][old_idx_netopil_LQS], com5['__Fe_H_LQS'][old_idx_netopil_LQS], yerr=com5['e__Fe_H_LQS'][old_idx_netopil_LQS], 
        capsize=1, c='darkorange', marker='o', ls='none', ms=2.5,ecolor='grey',elinewidth=0.5)
ax.errorbar(com5['RGC'][old_idx_netopil_HQS], com5['__Fe_H_HQS'][old_idx_netopil_HQS], yerr=com5['e__Fe_H_HQS'][old_idx_netopil_HQS],
        capsize=1, c='darkorange', marker='o', ls='none', ms=2.5,ecolor='grey',elinewidth=0.5)
ax.errorbar(com5['Rgc_donor'][old_idx_donor], com5['[Fe/H]_donor'][old_idx_donor], yerr=com5['e_[Fe/H]_donor'][old_idx_donor],
        capsize=1, c='k', marker='o', ls='none',ms=2.5,ecolor='grey',elinewidth=0.5, 
        label='Donor+20 ({0})'.format(len(old_idx_donor)))
ax.errorbar(com5['Rgc_spina'][old_idx_spina], com5['[Fe/H]_spina'][old_idx_spina], yerr=com5['e_[Fe/H]_spina'][old_idx_spina], 
        capsize=1, c= 'blue', marker='o',ls='none', ms=2.5, ecolor='grey',elinewidth=0.5,
        label='Spina+21 ({0})'.format(len(old_idx_spina)))
ax.errorbar(com5['Rgc_dias'][old_idx_dias], com5['[Fe/H]_dias'][old_idx_dias], yerr=com5['e_[Fe/H]_dias'][old_idx_dias],
        capsize=1, c='magenta', marker='o',ls='none', ms=2.5, ecolor='grey',elinewidth=0.5,
        label='Dias+21 ({0})'.format(len(old_idx_dias)))

ax.errorbar(cz30_dis.value, cz30_FeH, yerr=e_cz30_FeH, 
       ms=7, capsize=1, ecolor='red',elinewidth=0.5, c='red', ls='none', marker='*', 
       label='Czerink 30')
ax.errorbar(be34_dis.value, be34_FeH, yerr=e_be34_FeH, 
        ms=7, capsize=1, ecolor='orange',elinewidth=0.5, c='orange',marker='*', ls='none', 
        label='Berkeley 34')
ax.errorbar(be75_dis.value, be75_FeH, yerr=e_be75_FeH,
        ms=7, capsize=1, ecolor='k',elinewidth=0.5, c='green', marker='*', ls='none', 
        label='Berkeley 75') 
ax.errorbar(be76_dis.value, be76_FeH, yerr=e_be76_FeH, 
        ms=7, capsize=1, ecolor='blue',elinewidth=0.5, c='blue', marker='*',ls='none', 
        label='Berkeley 76')
"""
ax.plot(com5['Rgc_DAML'][old_idx_DAML], com5['[Fe/H]_DAML'][old_idx_DAML], 
        c='red', marker='o', ls='none', ms=2.5)
       # label='Dias+02 ({0})'.format(len(old_idx_DAML)))
ax.plot(com5['RGC'][old_idx_netopil_phot], com5['__Fe_H_Phot'][old_idx_netopil_phot],
        c='darkorange', marker='o', ls='none', ms=2.5)
       # label='Netopil+16 ({0})'.format(len(old_idx_netopil_phot) + len(old_idx_netopil_LQS)+ len(old_idx_netopil_HQS)))
ax.plot(com5['RGC'][old_idx_netopil_LQS], com5['__Fe_H_LQS'][old_idx_netopil_LQS],
        c='darkorange', marker='o', ls='none', ms=2.5)
ax.plot(com5['RGC'][old_idx_netopil_HQS], com5['__Fe_H_HQS'][old_idx_netopil_HQS],
        c='darkorange', marker='o', ls='none', ms=2.5)
ax.plot(com5['Rgc_donor'][old_idx_donor], com5['[Fe/H]_donor'][old_idx_donor],
        c='k', marker='o', ls='none',ms=2.5)
       #label='Donor+20 ({0})'.format(len(old_idx_donor)))
ax.plot(com5['Rgc_spina'][old_idx_spina], com5['[Fe/H]_spina'][old_idx_spina],
        c= 'blue', marker='o',ls='none', ms=2.5)
        #label='Spina+21 ({0})'.format(len(old_idx_spina)))
ax.plot(com5['Rgc_dias'][old_idx_dias], com5['[Fe/H]_dias'][old_idx_dias],
        c='magenta', marker='o',ls='none', ms=2.5)
        #label='Dias+21 ({0})'.format(len(old_idx_dias)))

ax.plot(cz30_dis.value, cz30_FeH,
       ms=8, mec='red', mew=2.8, mfc='none', ls='none', marker='o',
       label='Czerink 30')
ax.plot(be34_dis.value, be34_FeH, 
        ms=8, mec='orange', mew=2.8, mfc='none', marker='o', ls='none',
        label='Berkeley 34')
ax.plot(be75_dis.value, be75_FeH, 
        ms=8, mec='k', mew=2.8, mfc='none', marker='o', ls='none',
        label='Berkeley 75')
ax.plot(be76_dis.value, be76_FeH,
        ms=8, mec='blue', mew=2.8, mfc='none', marker='o',ls='none',
        label='Berkeley 76')
#ax.plot(x1, y1, 'r--', label='${0:.3f}R_{{GC}} + {1:.3f}$'.format(alpha1[0,0], alpha1[1,0]))
ax.plot(x1, result.best_values['a']*x1 + result.best_values['b'], 'r--',
        label='${0:.3f}R_{{GC}} {1:+.3f}$'.format(result.best_values['a'], result.best_values['b']))
ax.plot(x2, result2.best_values['a']*x2 + result2.best_values['b'], 'k--',
        label='${0:.3f}R_{{GC}} {1:+.3f}$'.format(result2.best_values['a'], result2.best_values['b']))
#ax.plot(x2, y2, 'k--', label='${0:.3f}R_{{GC}} {1:.3f}$'.format(alpha2[0,0], alpha2[1,0]))
ax.axvline(x=lim, ymin=0, ymax=1, c='grey', ls='--')
#ax.axvline(x=8.0, ymin=0, ymax=1, c='grey', ls='--')
#ax.text(3.83, -0.4, '${0:.3f}R_{{GC}} + {1:.3f}$'.format(m, c))
#ax.text(15, 0, '${0:.3f}R_{{GC}} {1:.3f}$'.format(m1, c1))
#ax.text(15.3, -0.82, '(b) t $\geq$ {0} Gyr, N={1}'.format(old_lim, len(old)), size=16,c='k')#,  bbox={'facecolor': 'white', 'alpha': 0.7, 'pad': 3})
ax.text(3.3, 0.85, '(b) t $\geq$ {0} Gyr, N={1}'.format(old_lim, len(old)+4), size=16,c='k')#,  bbox={'facecolor': 'white', 'alpha': 0.7, 'pad': 3})
#ax.set_xlabel('$R_{GC} (kpc)$', fontsize=18)
ax.set_ylabel('[Fe/H]', fontsize=18)
ax.tick_params(labelsize=16)
ax.xaxis.set_major_locator(loc)
ax.tick_params(labelbottom=False)
ax.set_ylim(ax0.get_ylim())
ax.set_xlim(ax0.get_xlim())
plt.legend(ncol=1, frameon=False)

ax2 = fig.add_subplot(413)
#ax2.errorbar(com5['Rgc_bocce'][young_idx_bocce], com5['[Fe/H]_bocce'][young_idx_bocce],yerr=com5['e_[Fe/H]_bocce'][young_idx_bocce]
#        mec='red', mfc='none', marker='o', ls='none', ms=2.5, 
#        label='BOCCE ({0})'.format(len(young_idx_bocce)))
"""
ax2.errorbar(com5['Rgc_DAML'][young_idx_DAML], com5['[Fe/H]_DAML'][young_idx_DAML], yerr=com5['e_[Fe/H]_DAML'][young_idx_DAML],
        mec='red', mfc='none', marker='o', ls='none', ms=2.5, ecolor='grey', elinewidth=0.5, capsize=1,
        label='Dias+02 ({0})'.format(len(young_idx_DAML)))
ax2.errorbar(com5['RGC'][young_idx_netopil_phot], com5['__Fe_H_Phot'][young_idx_netopil_phot], yerr=com5['e__Fe_H_Phot'][young_idx_netopil_phot],
        mec='darkorange', mfc='none', marker='o', ls='none', ms=2.5, ecolor='grey', elinewidth=0.5, capsize=1,
        label='Netopil+16 ({0})'.format(len(young_idx_netopil_phot) + len(young_idx_netopil_LQS)+ len(young_idx_netopil_HQS)))
ax2.errorbar(com5['RGC'][young_idx_netopil_LQS], com5['__Fe_H_LQS'][young_idx_netopil_LQS], yerr=com5['e__Fe_H_LQS'][young_idx_netopil_LQS],
        mec='darkorange', mfc='none', marker='o', ls='none', ms=2.5, ecolor='grey', elinewidth=0.5, capsize=1)
ax2.errorbar(com5['RGC'][young_idx_netopil_HQS], com5['__Fe_H_HQS'][young_idx_netopil_HQS], yerr=com5['e__Fe_H_HQS'][young_idx_netopil_HQS],
        mec='darkorange', mfc='none',marker='o', ls='none', ms=2.5, ecolor='grey',elinewidth=0.5, capsize=1)
ax2.errorbar(com5['Rgc_donor'][young_idx_donor], com5['[Fe/H]_donor'][young_idx_donor], yerr=com5['e_[Fe/H]_donor'][young_idx_donor],
        mec='k', mfc='none', marker='o',ls='none', ms=2.5, ecolor='grey', elinewidth=0.5, capsize=1,
        label='Donor+20 ({0})'.format(len(young_idx_donor)))
ax2.errorbar(com5['Rgc_spina'][young_idx_spina], com5['[Fe/H]_spina'][young_idx_spina], yerr=com5['e_[Fe/H]_spina'][young_idx_spina],
        mec='blue', mfc='none', marker='o', ls='none', ms=2.5, ecolor='grey', elinewidth=0.5, capsize=1,
        label='Spina+21 ({0})'.format(len(young_idx_spina)))
ax2.errorbar(com5['Rgc_dias'][young_idx_dias], com5['[Fe/H]_dias'][young_idx_dias], yerr=com5['e_[Fe/H]_dias'][young_idx_dias],
        mec='magenta', mfc='none', marker='o',ls='none', ms=2.5, alpha=0.7, ecolor='grey', elinewidth=0.5, capsize=1,
        label='Dias+21 ({0})'.format(len(young_idx_dias)))
ax2.errorbar(com5['Rgc_DAML'][young_idx_DAML], com5['[Fe/H]_DAML'][young_idx_DAML], yerr=com5['e_[Fe/H]_DAML'][young_idx_DAML],
        mec='red', mfc='none', marker='o', ls='none', ms=2.5, ecolor='grey', elinewidth=0.5, capsize=1,
        label='Dias+02 ({0})'.format(len(young_idx_DAML)))
"""
ax2.plot(com5['Rgc_dias'][young_idx_dias], com5['[Fe/H]_dias'][young_idx_dias], 
        mec='magenta', mfc='none', marker='o',ls='none', ms=2.5, alpha=0.7, 
        label='Dias+21 ({0})'.format(len(young_idx_dias)))
ax2.plot(com5['Rgc_spina'][young_idx_spina], com5['[Fe/H]_spina'][young_idx_spina], 
        mec='blue', mfc='none', marker='o', ls='none', ms=2.5,
        label='Spina+21 ({0})'.format(len(young_idx_spina)))
ax2.plot(com5['Rgc_donor'][young_idx_donor], com5['[Fe/H]_donor'][young_idx_donor],
        mec='k', mfc='none', marker='o',ls='none', ms=2.5,
        label='Donor+20 ({0})'.format(len(young_idx_donor)))
ax2.plot(com5['RGC'][young_idx_netopil_phot], com5['__Fe_H_Phot'][young_idx_netopil_phot], 
        mec='darkorange', mfc='none', marker='o', ls='none', ms=2.5, 
        label='Netopil+16 ({0})'.format(len(young_idx_netopil_phot) + len(young_idx_netopil_LQS)+ len(young_idx_netopil_HQS)))
ax2.plot(com5['RGC'][young_idx_netopil_LQS], com5['__Fe_H_LQS'][young_idx_netopil_LQS], 
        mec='darkorange', mfc='none', marker='o', ls='none', ms=2.5)
ax2.plot(com5['RGC'][young_idx_netopil_HQS], com5['__Fe_H_HQS'][young_idx_netopil_HQS],
        mec='darkorange', mfc='none',marker='o', ls='none', ms=2.5)
ax2.plot(com5['Rgc_DAML'][young_idx_DAML], com5['[Fe/H]_DAML'][young_idx_DAML],
        mec='red', mfc='none', marker='o', ls='none', ms=2.5,
        label='Dias+02 ({0})'.format(len(young_idx_DAML)))
#ax2.axvline(x=lim, ymin=0, ymax=1, c='grey', ls='--')
#ax2.plot(x3, y3, 'r--', label='${0:.3f}R_{{GC}} + {1:.3f}$'.format(alpha3[0,0], alpha3[1,0]))
#ax2.text(15, 0, '${0:.3f}R_{{GC}} + {1:.3f}$'.format(m2, c2))
#ax2.text(15.2, -0.82, '(c) t < {0} Gyr, N={1}'.format(old_lim,len(young)), size=16, c='k')#,bbox={'facecolor': 'white', 'alpha': 0.7, 'pad': 3})
ax2.text(3.3, 0.85, '(c) t < {0} Gyr, N={1}'.format(old_lim,len(young)), size=16, c='k')#,bbox={'facecolor': 'white', 'alpha': 0.7, 'pad': 3})
ax2.set_xlabel('$R_{GC} (kpc)$', fontsize=18)
ax2.set_ylabel('[Fe/H]', fontsize=18)
ax2.xaxis.set_major_locator(loc)
ax2.tick_params(labelbottom=False)
ax2.set_xlim(ax.get_xlim())
ax2.set_ylim(ax.get_ylim())
ax2.tick_params(labelsize=16)
handles, labels = ax2.get_legend_handles_labels()
ax2.legend(reversed(handles), reversed(labels), frameon=False)

ax3 = fig.add_subplot(414)
"""
ax3.errorbar(com5['Rgc_DAML'][young_idx_DAML], com5['[Fe/H]_DAML'][young_idx_DAML], yerr=com5['e_[Fe/H]_DAML'][young_idx_DAML],
        mec='red', mfc='none', marker='o', ls='none', ms=2.5, ecolor='grey', elinewidth=0.5, capsize=1,
        label='Dias+02 ({0})'.format(len(young_idx_DAML)))
ax3.errorbar(com5['RGC'][young_idx_netopil_phot], com5['__Fe_H_Phot'][young_idx_netopil_phot], yerr=com5['e__Fe_H_Phot'][young_idx_netopil_phot],
        mec='darkorange', mfc='none', marker='o', ls='none', ms=2.5, ecolor='grey', elinewidth=0.5, capsize=1,
        label='Netopil+16 ({0})'.format(len(young_idx_netopil_phot) + len(young_idx_netopil_LQS)+ len(young_idx_netopil_HQS)))
ax3.errorbar(com5['RGC'][young_idx_netopil_LQS], com5['__Fe_H_LQS'][young_idx_netopil_LQS], yerr=com5['e__Fe_H_LQS'][young_idx_netopil_LQS],
        mec='darkorange', mfc='none', marker='o', ls='none', ms=2.5, ecolor='grey', elinewidth=0.5, capsize=1)
ax3.errorbar(com5['RGC'][young_idx_netopil_HQS], com5['__Fe_H_HQS'][young_idx_netopil_HQS], yerr=com5['e__Fe_H_HQS'][young_idx_netopil_HQS],
        mec='darkorange', mfc='none',marker='o', ls='none', ms=2.5, ecolor='grey',elinewidth=0.5, capsize=1)
ax3.errorbar(com5['Rgc_donor'][young_idx_donor], com5['[Fe/H]_donor'][young_idx_donor], yerr=com5['e_[Fe/H]_donor'][young_idx_donor],
        mec='k', mfc='none', marker='o',ls='none', ms=2.5, ecolor='grey', elinewidth=0.5, capsize=1,
        label='Donor+20 ({0})'.format(len(young_idx_donor)))
ax3.errorbar(com5['Rgc_spina'][young_idx_spina], com5['[Fe/H]_spina'][young_idx_spina], yerr=com5['e_[Fe/H]_spina'][young_idx_spina],
        mec='blue', mfc='none', marker='o', ls='none', ms=2.5, ecolor='grey', elinewidth=0.5, capsize=1,
        label='Spina+21 ({0})'.format(len(young_idx_spina)))
ax3.errorbar(com5['Rgc_dias'][young_idx_dias], com5['[Fe/H]_dias'][young_idx_dias], yerr=com5['e_[Fe/H]_dias'][young_idx_dias],
        mec='magenta', mfc='none', marker='o',ls='none', ms=2.5, alpha=0.7, ecolor='grey', elinewidth=0.5, capsize=1,
        label='Dias+21 ({0})'.format(len(young_idx_dias)))

ax3.errorbar(com5['Rgc_DAML'][old_idx_DAML], com5['[Fe/H]_DAML'][old_idx_DAML], yerr=com5['e_[Fe/H]_DAML'][old_idx_DAML], 
        capsize=1, c='red', marker='o', ls='none', ms=2.5,ecolor='grey',elinewidth=0.5, 
        label='Dias+02 ({0})'.format(len(old_idx_DAML)))
ax3.errorbar(com5['RGC'][old_idx_netopil_phot], com5['__Fe_H_Phot'][old_idx_netopil_phot], yerr=com5['e__Fe_H_Phot'][old_idx_netopil_phot],
        capsize=1, c='darkorange', marker='o', ls='none', ms=2.5, ecolor='grey',elinewidth=0.5,
        label='Netopil+16 ({0})'.format(len(old_idx_netopil_phot) + len(old_idx_netopil_LQS)+ len(old_idx_netopil_HQS)))
ax3.errorbar(com5['RGC'][old_idx_netopil_LQS], com5['__Fe_H_LQS'][old_idx_netopil_LQS], yerr=com5['e__Fe_H_LQS'][old_idx_netopil_LQS], 
        capsize=1, c='darkorange', marker='o', ls='none', ms=2.5,ecolor='grey',elinewidth=0.5)
ax3.errorbar(com5['RGC'][old_idx_netopil_HQS], com5['__Fe_H_HQS'][old_idx_netopil_HQS], yerr=com5['e__Fe_H_HQS'][old_idx_netopil_HQS],
        capsize=1, c='darkorange', marker='o', ls='none', ms=2.5,ecolor='grey',elinewidth=0.5)
ax3.errorbar(com5['Rgc_donor'][old_idx_donor], com5['[Fe/H]_donor'][old_idx_donor], yerr=com5['e_[Fe/H]_donor'][old_idx_donor],
        capsize=1, c='k', marker='o', ls='none',ms=2.5,ecolor='grey',elinewidth=0.5, 
        label='Donor+20 ({0})'.format(len(old_idx_donor)))
ax3.errorbar(com5['Rgc_spina'][old_idx_spina], com5['[Fe/H]_spina'][old_idx_spina], yerr=com5['e_[Fe/H]_spina'][old_idx_spina], 
        capsize=1, c= 'blue', marker='o',ls='none', ms=2.5, ecolor='grey',elinewidth=0.5,
        label='Spina+21 ({0})'.format(len(old_idx_spina)))
ax3.errorbar(com5['Rgc_dias'][old_idx_dias], com5['[Fe/H]_dias'][old_idx_dias], yerr=com5['e_[Fe/H]_dias'][old_idx_dias],
        c='magenta', marker='o',ls='none', ms=2.5, ecolor='grey',elinewidth=0.5,
        label='Dias+21 ({0})'.format(len(old_idx_dias)))

ax3.errorbar(cz30_dis.value, cz30_FeH, yerr=e_cz30_FeH, 
       ms=7, capsize=1, ecolor='red',elinewidth=0.5, c='red', ls='none', marker='*', 
       label='Czerink 30')
ax3.errorbar(be34_dis.value, be34_FeH, yerr=e_be34_FeH, 
        ms=7, capsize=1, ecolor='orange',elinewidth=0.5, c='orange',marker='*', ls='none', 
        label='Berkeley 34')
ax3.errorbar(be75_dis.value, be75_FeH, yerr=e_be75_FeH,
        ms=7, capsize=1, ecolor='k',elinewidth=0.5, c='green', marker='*', ls='none', 
        label='Berkeley 75') 
ax3.errorbar(be76_dis.value, be76_FeH, yerr=e_be76_FeH, 
        ms=7, capsize=1, ecolor='blue',elinewidth=0.5, c='blue', marker='*',ls='none', 
        label='Berkeley 76')
"""
ax3.plot(com5['Rgc_dias'][young_idx_dias], com5['[Fe/H]_dias'][young_idx_dias],
        mec='magenta', mfc='none', marker='o',ls='none', ms=2.5, alpha=0.7,
        label='Dias+21 ({0})'.format(len(young_idx_dias)))
ax3.plot(com5['Rgc_DAML'][young_idx_DAML], com5['[Fe/H]_DAML'][young_idx_DAML],
        mec='red', mfc='none', marker='o', ls='none', ms=2.5,
        label='Dias+02 ({0})'.format(len(young_idx_DAML)))
ax3.plot(com5['RGC'][young_idx_netopil_phot], com5['__Fe_H_Phot'][young_idx_netopil_phot],
        mec='darkorange', mfc='none', marker='o', ls='none', ms=2.5,
        label='Netopil+16 ({0})'.format(len(young_idx_netopil_phot) + len(young_idx_netopil_LQS)+ len(young_idx_netopil_HQS)))
ax3.plot(com5['RGC'][young_idx_netopil_LQS], com5['__Fe_H_LQS'][young_idx_netopil_LQS],
        mec='darkorange', mfc='none', marker='o', ls='none', ms=2.5)
ax3.plot(com5['RGC'][young_idx_netopil_HQS], com5['__Fe_H_HQS'][young_idx_netopil_HQS],
        mec='darkorange', mfc='none',marker='o', ls='none', ms=2.5)
ax3.plot(com5['Rgc_donor'][young_idx_donor], com5['[Fe/H]_donor'][young_idx_donor],
        mec='k', mfc='none', marker='o',ls='none', ms=2.5,
        label='Donor+20 ({0})'.format(len(young_idx_donor)))
ax3.plot(com5['Rgc_spina'][young_idx_spina], com5['[Fe/H]_spina'][young_idx_spina],
        mec='blue', mfc='none', marker='o', ls='none', ms=2.5,
        label='Spina+21 ({0})'.format(len(young_idx_spina)))

ax3.plot(com5['Rgc_DAML'][old_idx_DAML], com5['[Fe/H]_DAML'][old_idx_DAML],
        c='red', marker='o', ls='none', ms=2.5,
        label='Dias+02 ({0})'.format(len(old_idx_DAML)))
ax3.plot(com5['RGC'][old_idx_netopil_phot], com5['__Fe_H_Phot'][old_idx_netopil_phot],
        c='darkorange', marker='o', ls='none', ms=2.5, 
        label='Netopil+16 ({0})'.format(len(old_idx_netopil_phot) + len(old_idx_netopil_LQS)+ len(old_idx_netopil_HQS)))
ax3.plot(com5['RGC'][old_idx_netopil_LQS], com5['__Fe_H_LQS'][old_idx_netopil_LQS],
        c='darkorange', marker='o', ls='none', ms=2.5)
ax3.plot(com5['RGC'][old_idx_netopil_HQS], com5['__Fe_H_HQS'][old_idx_netopil_HQS],
        c='darkorange', marker='o', ls='none', ms=2.5)
ax3.plot(com5['Rgc_donor'][old_idx_donor], com5['[Fe/H]_donor'][old_idx_donor],
        c='k', marker='o', ls='none',ms=2.5,
        label='Donor+20 ({0})'.format(len(old_idx_donor)))
ax3.plot(com5['Rgc_spina'][old_idx_spina], com5['[Fe/H]_spina'][old_idx_spina],
        c= 'blue', marker='o',ls='none', ms=2.5, 
        label='Spina+21 ({0})'.format(len(old_idx_spina)))
ax3.plot(com5['Rgc_dias'][old_idx_dias], com5['[Fe/H]_dias'][old_idx_dias],
        c='magenta', marker='o',ls='none', ms=2.5,
        label='Dias+21 ({0})'.format(len(old_idx_dias)))

ax3.plot(cz30_dis.value, cz30_FeH,
       ms=8, mec='red', mew=2.8, mfc='none', ls='none', marker='o',
       label='Czerink 30')
ax3.plot(be34_dis.value, be34_FeH,
        ms=8, mec='orange', mew=2.8, mfc='none', marker='o', ls='none',
        label='Berkeley 34')
ax3.plot(be75_dis.value, be75_FeH, 
        ms=8, mec='k', mew=2.8, mfc='none', marker='o', ls='none',
        label='Berkeley 75')
ax3.plot(be76_dis.value, be76_FeH, 
        ms=8, mec='blue', mew=2.8, mfc='none',marker='o',ls='none',
        label='Berkeley 76')
#ax3.axvline(x=lim, ymin=0, ymax=1, c='grey', ls='--')
#ax3.text(17.25, -0.82, '(d) all, N={0}'.format(len(old) + len(young)), size=16, c='k')#, bbox={'facecolor': 'white', 'alpha': 0.7, 'pad': 3})
ax3.text(3.3, 0.85, '(d) all, N={0}'.format(len(old) + len(young)+4), size=16, c='k')#, bbox={'facecolor': 'white', 'alpha': 0.7, 'pad': 3})
ax3.set_xlabel('$R_{GC}$ (kpc)', fontsize=18)
ax3.set_ylabel('[Fe/H]', fontsize=18)
loc = ticker.MultipleLocator(base=2)
ax3.xaxis.set_major_locator(loc)
ax3.set_xlim(ax.get_xlim())
ax3.set_ylim(ax.get_ylim())
ax3.tick_params(labelsize=16)
plt.savefig('RMD_{0}_new.pdf'.format(lim))
"""
fig = plt.figure()
ax = fig.add_subplot(111)
ax.plot(BOSSINI_rgc, BOSSINI['age'], c='grey', marker='o', ms=2.5, ls='none')
ax.plot(BOCCE['Rgc (Rgc,sun=8)'], BOCCE['age (Gyr)'], 'ko', ms=2.5)
ax.plot(cz30_dis, cz30_age, 'r*', label='Czerink 30')
ax.plot(be34_dis, be34_age, c='orange',marker='*', label='Berkeley 34')
ax.plot(be75_dis, be75_age, 'g*', label='Berkeley 75')
ax.plot(be76_dis, be76_age, 'b*', label='Berkeley 76')
ax.set_xlabel('$R_{GC} (kpc)$')
ax.set_ylabel('age (Gyr)')

test = BOSSINI[np.where(BOSSINI['age'] > 1.0)]
test_dis = BOSSINI_rgc[np.where(BOSSINI['age'] > 1.0)]
test2 = BOCCE[np.where(BOCCE['age (Gyr)'] > 1.0)]
fig2 = plt.figure()
ax2 = fig2.add_subplot(111)
ax2.plot(test_dis, test['[Fe/H]'], c='grey', marker='o', ms=2.5, ls='none')
ax2.plot(test2['Rgc (Rgc,sun=8)'], test2['[Fe/H]'], 'ko', ms=2.5)
ax2.plot(cz30_dis, cz30_FeH, 'r*', label='Czerink 30')
ax2.plot(be34_dis, be34_FeH, c='orange',marker='*', label='Berkeley 34')
ax2.plot(be75_dis, be75_FeH, 'g*', label='Berkeley 75')
ax2.plot(be76_dis, be76_FeH, 'b*', label='Berkeley 76')
ax2.set_xlabel('$R_{GC} (kpc)$')
ax2.set_ylabel('$[Fe/H]$')

fig = plt.figure()
ax = fig.add_subplot(111)
ax.set_xlabel('$R_{GC}$ (kpc)')
ax.set_ylabel('[Fe/H]')
ax.plot(dat['dist_galcen'][np.where(dat['age']>1)], dat['[Fe/H]'][np.where(dat['age']>1)], 'ko', ms=2.5, alpha=0.7)
ax.plot(cz30_dis, cz30_FeH, 'r*', label='Czerink 30')
ax.plot(be34_dis, be34_FeH, c='orange',marker='*', label='Berkeley 34', ls='none')
ax.plot(be75_dis, be75_FeH, 'g*', label='Berkeley 75')
ax.plot(be76_dis, be76_FeH, 'b*', label='Berkeley 76')
plt.legend()

plt.scatter(-dat['X'][np.where(dat['age']>1)], dat['Y'][np.where(dat['age']>1)], c=dat['[Fe/H]'][np.where(dat['age']>1)], s=2)
plt.scatter(-cz30.x, cz30.y, c=cz30_FeH, marker='s', label='Czernik 30', s=6)
plt.clim(min_, max_)
plt.scatter(-be34.x, be34.y, c=be34_FeH, marker='^', label='Berkeley 34', s=6)
plt.clim(min_, max_)
plt.scatter(-be75.x, be75.y, c=be75_FeH, marker='p', label='Berkeley 75', s=6)
plt.clim(min_, max_)
plt.scatter(-be76.x, be76.y, c=be76_FeH, marker='*', label='Berkeley 76', s=6)
plt.clim(min_, max_)
ax.axvline(x=8.0, ymin=0, ymax=1, c='grey', ls='--')
ax.axhline(y=0.0, xmin=0, xmax=1, c='grey', ls='--')
plt.legend()
plt.colorbar().set_label('[Fe/H]')
"""
